@@ -26,6 +26,50 @@
 #'  If `tmpdir` is a non-empty folder, a random subdirectory will be used.
 #' @param rmtmp (optional) Logical: should temporary files be removed?
 #'  (Default: TRUE)
+#' @param gipp (optional) Ground Image Processing Parameters (GIPP)
+#'  to be passed to Sen2Cor.
+#'  It is possible to specify both the path of an existing XML file 
+#'  or a list of parameters in the form `parameter_name = "value"`, where 
+#'  `parameter_name` is the name of the parameter as specified in the 
+#'  XML file (case insensitive), and `"value"` is the character value 
+#'  which the user wants to set 
+#'  (notice that, in the case the user wants to specify the value `NONE`,
+#'  both `"NONE"` and `NA` can be used, but not `NULL`, which has the effect
+#'  to maintain the value specified in the XML file).
+#'  
+#'  For details about the GIPP parameters, refer to the Sen2Cor documentation
+#'  (v. [2.5.5](http://step.esa.int/main/third-party-plugins-2/sen2cor/sen2cor_v2-5-5/) 
+#'  or [2.8.0](http://step.esa.int/main/third-party-plugins-2/sen2cor/sen2cor_v2-8/):
+#'  see the "Schemas of the GIPP file" at the end of each page).
+#'  _Note_: this argument takes effect only in the current execution of 
+#'  `sen2cor()` function.
+#' @param use_dem (optional) Logical: 
+#'  if TRUE, Sen2Cor is set to use a Digital Elevation Model for topographic 
+#'  correction (reflecting what is done for Level-2A SAFE images provided by ESA Hub);
+#'  if FALSE, it is set not to perform topographic correction (reflecting the 
+#'  current default Sen2Cor behaviour);
+#'  if NA (default), the option set in the XML GIPP configuration file 
+#'  used by sen2r (stored in the default sen2r settings directory) is respected;
+#'  in case the user never edited it,
+#'  the current default setting is not to perform topographic correction.
+#'  
+#'  _Notes_: 
+#'  1. if TRUE, the path used to read or store DEM files 
+#'      and the online source used to download missing DEM tiles
+#'      are respectively the `DEM_Directory` and `DEM_Reference` parameters
+#'      set in the default sen2r GIPP XML file (the user can read them
+#'      with the function `read_gipp(c("DEM_Directory", "DEM_Reference"))`).
+#'      In case one or both these parameters were set to `"NONE"`, 
+#'      a subdirectory `"srtm90"` of the default sen2r directory is used as
+#'      DEM directory, and/or the [CGIAR SRTM 90m](http://srtm.csi.cgiar.org/) 
+#'      is set as online source.
+#'      To set another directory or reference, use argument `gipp` in the form
+#'      `gipp = list(DEM_Directory = tempdir(), DEM_Reference ="another_reference", ...)`
+#'      (replacing `tempdir()` with the desired path and specifying the online resource).
+#'  2. Currently the default value is NA in order to grant backward 
+#'      compatibility. In a future release of sen2r, the default value will be
+#'      set to TRUE, so to grant homogeneity between Level-2A products downloaded
+#'      from ESA Hub and generated using Sen2Cor.
 #' @param tiles Vector of Sentinel-2 Tile strings (5-length character) to be
 #'  processed (default: process all the tiles found in the input L1C products).
 #' @param parallel (optional) Logical: if TRUE, Sen2Cor instances are launched
@@ -39,8 +83,8 @@
 #'  (it is used when the function is called by `sen2r()`).
 #' @param .log_output (optional) Internal parameter
 #'  (it is used when the function is called by `sen2r()`).
-#' @return Vector character with the list ot the output products (being corrected or already
-#'  existing)
+#' @return Vector character with the list ot the output products
+#'  (being corrected or already existing).
 #'
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
 #' @note License: GPL 3.0
@@ -52,20 +96,41 @@
 #'
 #' @examples
 #' \dontrun{
-#' pos <- st_sfc(st_point(c(12.0, 44.8)), crs=st_crs(4326))
-#' time_window <- as.Date(c("2017-05-01","2017-07-30"))
-#' example_s2_list <- s2_list(spatial_extent=pos, tile="32TQQ", time_interval=time_window)
-#' s2_download(example_s2_list, outdir=tempdir())
-#' sen2cor(names(example_s2_list)[1], l1c_dir=tempdir(), outdir=tempdir())
+#' # Download an L1C SAFE product
+#' example_s2_list <- s2_list(
+#'   spatial_extent = st_sfc(st_point(c(12.0, 44.8)), crs=st_crs(4326)), 
+#'   tile = "32TQQ", 
+#'   time_interval = as.Date(c("2017-05-01","2017-07-30"))
+#' )
+#' s2_download(example_s2_list, outdir = tempdir())
+#' 
+#' # Correct it applying a topographic correction
+#' sen2cor(
+#'   names(example_s2_list)[1], 
+#'   l1c_dir = tempdir(), 
+#'   outdir = tempdir(),
+#'   use_dem = TRUE
+#' )
 #' }
 
-sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
-                    tmpdir = NA, rmtmp = TRUE,
-                    tiles=NULL, parallel=FALSE, overwrite=FALSE,
-                    .log_message=NA, .log_output=NA) {
+sen2cor <- function(
+  l1c_prodlist = NULL, 
+  l1c_dir = NULL, 
+  outdir = NULL, 
+  proc_dir = NA,
+  tmpdir = NA, 
+  rmtmp = TRUE,
+  gipp = NULL,
+  use_dem = NA,
+  tiles = NULL, 
+  parallel = FALSE, 
+  overwrite = FALSE,
+  .log_message = NA, 
+  .log_output = NA
+) {
   
   # to avoid NOTE on check
-  i <- NULL
+  i <- creation_datetime <- id_baseline <- path <- name <- NULL
   
   # load Sen2Cor executable path
   binpaths <- tryCatch(
@@ -73,6 +138,10 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
     warning = stop
   )
   
+  # Use a copy of the default GIPP XML, setting parameters properly
+  gipp_curr_path <- tempfile(pattern = "L2A_GIPP_", fileext = ".xml")
+  set_gipp(gipp = gipp, gipp_path = gipp_curr_path, use_dem = use_dem)
+  
   # get version
   sen2cor_version_raw0 <- system(paste(binpaths$sen2cor, "-h"), intern = TRUE)
   sen2cor_version_raw1 <- sen2cor_version_raw0[grep(
@@ -119,7 +188,7 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
     format = "vector", abort = FALSE, simplify = TRUE
   )
   l1c_prodlist <- l1c_prodlist[which(l1c_prodlist_level == "1C")]
-
+  
   # if no products were found, exit
   if (length(l1c_prodlist) == 0) {
     print_message(
@@ -187,11 +256,23 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
       basename(sel_l2a)
     )
     sel_l2a_exi <- list.files(dirname(sel_l2a), sel_l2a_regex, full.names = TRUE)
-    if (length(sel_l2a_exi) > 0) {
-      sel_l2a <- sel_l2a_exi[1]
+    # exclude invalid SAFEs
+    sel_l2a_exi <- sel_l2a_exi[safe_isvalid(sel_l2a_exi)]
+    sel_l2a_meta <- safe_getMetadata(
+      sel_l2a_exi, 
+      info = c("creation_datetime", "id_baseline", "tiles")
+    )
+    if (nrow(sel_l2a_meta) > 0) {
+      # order by ingestion date (recent first) and baseline (locally corrected and newer first)
+      sel_l2a_meta <- sel_l2a_meta[
+        order(-creation_datetime, -id_baseline), 
+        path := file.path(dirname(sel_l2a), name)
+        ]
+      # replace the defined sel_l2a with the actual safe to be used
+      sel_l2a <- sel_l2a_meta[1,path] 
     }
-    # TODO order by baseline, ingestion date
-
+    
+    
     ## Set the tiles vectors (existing, required, ...)
     # existing L1C tiles within input product
     sel_l1c_tiles_existing <- safe_getMetadata(
@@ -199,14 +280,10 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
       "id_tile", format = "vector", simplify = TRUE
     )
     # L2A tiles already existing
-    sel_l2a_tiles_existing <- if (file.exists(sel_l2a)) {
-      safe_getMetadata(
-        list.files(file.path(sel_l2a,"GRANULE")), 
-        "id_tile", format = "vector"
-      )
-    } else {
-      character(0)
-    }
+    sel_l2a_tiles_existing <- safe_getMetadata(
+      list.files(file.path(sel_l2a,"GRANULE")),
+      "id_tile", format = "vector", simplify = TRUE
+    )
     # L2A tiles required as output (already existing or not)
     sel_l2a_tiles_required <- if (length(tiles)==0) {
       sel_l1c_tiles_existing
@@ -320,6 +397,7 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
         # paste(binpaths$sen2cor, "--refresh", sel_l1c),
         paste(
           binpaths$sen2cor,
+          "--GIP_L2A", gipp_curr_path,
           if (sen2cor_version>=package_version("2.8.0")) {paste("--output_dir", sen2cor_out_l2a)},
           if (sen2cor_version<package_version("2.8.0")) {"--refresh"},
           sel_l1c
@@ -340,7 +418,7 @@ sen2cor <- function(l1c_prodlist=NULL, l1c_dir=NULL, outdir=NULL, proc_dir=NA,
           file.path(sen2cor_out_l2a,sen2cor_out_l2a_basename),
           file.path(dirname(sen2cor_out_l2a),sen2cor_out_l2a_basename)
         )
-        file.remove(sen2cor_out_l2a)
+        unlink(sen2cor_out_l2a, recursive = TRUE)
         sen2cor_out_l2a <- file.path(dirname(sen2cor_out_l2a),sen2cor_out_l2a_basename)
         sel_l2a <- file.path(dirname(sel_l2a), sen2cor_out_l2a_basename)
       }
